==> trip-0.1.0.tar.gz: trip-0.1.0/tripstack/tripcore/TRIPAuthData.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF ,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */



static const char* const TRIPAuthData_cxx_Version = 
"$Id: TRIPAuthData.cxx,v 1.1 2000/11/02 02:10:53 surendra Exp $";

#include "TRIPAuthData.hxx"
#include "TRIPUtil.hxx"
#include "cpLog.h"

TRIPAuthData::TRIPAuthData(const TRIPAuthData& other) 
{
     copyObj(other);
}

TRIPAuthData& 
TRIPAuthData::operator=(const TRIPAuthData& other)
{
    if(this != &other)
    {
        copyObj(other);
    }
    return(*this);
}

void 
TRIPAuthData::dump(ostream& os) const
{
    os.width(25);
    os << "**AuthData**" << endl;
    os.width(25);
    os << "Length:" << static_cast<int>(_length) << endl;
    os.width(25);
    os << "Itad:" << static_cast<int>(_itad) << endl;
    os.width(25);
    os << "TRIPId:" << _tripId << endl;
    os.width(25);
    os << "Attribute code:" << static_cast<int>(_attrCode) << endl;
    os.width(25);
    os << "Auth  mechanism:" << static_cast<int>(_authMech) << endl;
    os.width(25);
    os << "Data:" << *_data << endl;
}

void 
TRIPAuthData::writeData(int id) const throw(VNetworkException&)
{
    struct shipIt {
        u_int16_t        length;
        u_int16_t        itad;
        u_int32_t        tripId;
        u_int8_t         attrCode;
        u_int8_t         authMech;
    } sIt;

    sIt.length = htons(_length);
    sIt.itad = htons(_itad);
    sIt.tripId = htonl(_tripId.getId());
    sIt.attrCode = _attrCode;
    sIt.authMech = _authMech;
    TRIPUtil::writeData(id, &sIt, sizeof(struct shipIt));
}

TRIPAuthData::TRIPAuthData(const char* buf) 
        throw (TRIPBadDataException&)
{
    struct shipIt {
        u_int16_t        length;
        u_int16_t        itad;
        u_int32_t        tripId;
        u_int8_t         attrCode;
        u_int8_t         authMech;
    } sIt;

    memcpy(&sIt, buf, sizeof(struct shipIt));
    _length = ntohl(sIt.length);
    _itad = ntohs(sIt.itad);
    _tripId = TRIPId(sIt.tripId);
    _attrCode = ntohs(sIt.attrCode);
    _authMech = ntohs(sIt.authMech);

    //Extract data past attrHeader+10bytes(includes itad and data length)
    _data = new TRIPData(buf+10, _length - 10);
}

void 
TRIPAuthData::copyObj(const TRIPAuthData& other)
{
    _length = other._length;
    _itad = other._itad;
    _tripId = other._tripId;
    _attrCode = other._attrCode;
    _authMech = other._authMech;
    _data = other._data;
}

==> trip-1.0.0.tar.gz: trip-1.0.0/tripstack/tripcore/TRIPAuthData.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */



static const char* const TRIPAuthData_cxx_Version = 
"$Id: TRIPAuthData.cxx,v 1.4 2001/01/20 02:28:33 sprajpat Exp $";

#include <netinet/in.h>

#include "TRIPAuthData.hxx"
#include "TRIPUtil.hxx"
#include "cpLog.h"

static const int DUMP_LABEL_WIDTH=25;
int TRIPAuthData::_fixedHeaderLength = 10;

TRIPAuthData::TRIPAuthData(const TRIPAuthData& other) 
{
     copyObj(other);
}

TRIPAuthData& 
TRIPAuthData::operator=(const TRIPAuthData& other)
{
    if(this != &other)
    {
        copyObj(other);
    }
    return(*this);
}

void 
TRIPAuthData::dump(ostream& os) const
{
    os.width(DUMP_LABEL_WIDTH);
    os << "**AuthData**" << endl;
    os.width(DUMP_LABEL_WIDTH);
    os << "Length:" << static_cast<int>(_length) << endl;
    os.width(DUMP_LABEL_WIDTH);
    os << "Itad:" << static_cast<int>(_itad) << endl;
    os.width(DUMP_LABEL_WIDTH);
    os << "TRIPId:" << _tripId << endl;
    os.width(DUMP_LABEL_WIDTH);
    os << "Attribute code:" << static_cast<int>(_attrCode) << endl;
    os.width(DUMP_LABEL_WIDTH);
    os << "Auth  mechanism:" << static_cast<int>(_authMech) << endl;
    os.width(DUMP_LABEL_WIDTH);
    os << "Data:" << *_data << endl;
}

void 
TRIPAuthData::writeData(int id) const throw(VNetworkException&)
{
    struct shipIt {
        u_int16_t        length;
        u_int16_t        itad;
        u_int32_t        tripId;
        u_int8_t         attrCode;
        u_int8_t         authMech;
    } sIt;

    sIt.length = htons(_length);
    sIt.itad = htons(_itad);
    sIt.tripId = htonl(_tripId.getId());
    sIt.attrCode = _attrCode;
    sIt.authMech = _authMech;
    TRIPUtil::writeData(id, &sIt, sizeof(struct shipIt));
    if(_data->length())
    {
        TRIPUtil::writeData(id, _data->getData(), _data->length());
    }
}

TRIPAuthData::TRIPAuthData(const char* buf) 
        throw (TRIPBadDataException&)
{
    struct shipIt {
        u_int16_t        length;
        u_int16_t        itad;
        u_int32_t        tripId;
        u_int8_t         attrCode;
        u_int8_t         authMech;
    } sIt;

    memcpy(&sIt, buf, sizeof(struct shipIt));
    _length = ntohs(sIt.length);
    _itad = ntohs(sIt.itad);
    _tripId = TRIPId(ntohl(sIt.tripId));
    _attrCode = sIt.attrCode;
    _authMech = sIt.authMech;

    //Extract data past attrHeader+10bytes(includes itad and data length)
    _data = new TRIPData(buf+_fixedHeaderLength, _length - _fixedHeaderLength);
}

void 
TRIPAuthData::copyObj(const TRIPAuthData& other)
{
    _length = other._length;
    _itad = other._itad;
    _tripId = other._tripId;
    _attrCode = other._attrCode;
    _authMech = other._authMech;
    _data = other._data;
}
